"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
/**
 * useFetchMarketCode hook is used to fetch market codes from upbit api
 * @returns Object with the market codes and a loading state.
 */
function useFetchMarketCode(option = { debug: false }) {
    const REST_API_URL = 'https://api.upbit.com/v1/market/all?isDetails=false';
    const [isLoading, setIsLoading] = (0, react_1.useState)(true);
    const [marketCodes, setMarketCodes] = (0, react_1.useState)([]);
    const fetchMarketCodes = () => __awaiter(this, void 0, void 0, function* () {
        try {
            const response = yield fetch(REST_API_URL);
            if (!response.ok) {
                throw new Error('Failed to fetch market codes');
            }
            const json = yield response.text();
            const result = JSON.parse(json);
            setMarketCodes(result);
            if (option.debug) {
                console.log('Market codes fetched:', result);
            }
        }
        catch (error) {
            console.error('Error fetching market codes:', error);
        }
        finally {
            setIsLoading(false);
        }
    });
    (0, react_1.useEffect)(() => {
        fetchMarketCodes().catch(error => {
            console.error('Error fetching market codes:', error);
        });
    }, []);
    return { isLoading, marketCodes };
}
exports.default = useFetchMarketCode;
